# **Assignment - Topsis**

---
#### **Step 1** - Learn Topsis - <a href="https://www.youtube.com/watch?v=kfcN7MuYVeI">Link-1</a>, <a href="https://www.youtube.com/watch?v=9P9Gs8o9oHk">Link-2</a>

#### **Step 2** - Learn "How to publish Python package" on <a href="https://pypi.org/">pypi.org</a> - <a href="https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56">Link-1</a>, <a href="https://www.youtube.com/watch?v=Qs91v2Tofys">Link-2</a>, <a href="https://www.youtube.com/watch?v=tEFkHEKypLI">Link-3</a>

#### **Step 3** - Explore "Assignment - Topsis.pdf" for more information.
